# ServiceMap

> see https://aka.ms/autorest

This is the AutoRest configuration file for ServiceMap.



---
## Getting Started
To build the SDK for ServiceMap, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration
Following are the settings for using this specification with [AutoRest](https://aka.ms/autorest) tool to validation and optionally generate SDK.

### Azure Validator Suppressions

Suppressed Rule | Reason
----------------|--------
R3023 OperationsAPIImplementation | Service map is sharing RP with Log Analytics, so this operaration won't reach ServiceMap's service endpoint. Hence this rule is not applicable.

```yaml
model-validator: true 
semantic-validator: true
azure-validator: true
directive:
  suppress:
    - R3023
```

### Basic Information
These are the global settings for the ServiceMap API.

``` yaml
openapi-type: arm
tag: package-2015-11-preview
```


### Tag: package-2015-11-preview

These settings apply only when `--tag=package-2015-11-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-11-preview'
input-file:
- Microsoft.OperationalInsights/preview/2015-11-01-preview/arm-service-map.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  namespace: servicemap
  clear-output-folder: true
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2015-11-preview
```

### Tag: package-2015-11-preview and go

These settings apply only when `--tag=package-2015-11-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2015-11-preview' && $(go)
output-folder: $(go-sdk-folder)/services/preview/operationalinsights/mgmt/2015-11-01-preview/servicemap
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.operationalinsights.servicemap
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-operationalinsights/servicemap
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-11-preview
```

### Tag: package-2015-11-preview and java

These settings apply only when `--tag=package-2015-11-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-11-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.servicemap.v2015_11_01_preview
  output-folder: $(azure-libraries-for-java-folder)/servicemap/resource-manager/v2015_11_01_preview
regenerate-manager: true
generate-interface: true
```


